@@ -1,11 +1,8 @@
 from abc import ABC, abstractmethod
 from typing import Callable
 from pywirelessmbus.utils import WMbusMessage
-import logging
 from pywirelessmbus.utils.utils import NOOP
 
-logger = logging.getLogger(__name__)
-
 
 class Device(ABC):
     on_set_aes_key: Callable[[int, str, bytes], None]
